Crate zenoh_flow_records

Crate zenoh_flow_records 

This crate exposes *Record structures. A record in Zenoh-Flow is a description of a data flow (or part of it) that is tied to a specific infrastructure and deployment.

In particular, a DataFlowRecord represents a single deployment of a FlattenedDataFlowDescriptor on an infrastructure: all the nodes have been assigned to a Zenoh-Flow runtime. This is why to each DataFlowRecord is associated a unique InstanceId which uniquely identifies it.

⚠️ Internal usage

This crate is (mostly) intended for internal usage within the Zenoh-Flow project.

Structs

DataFlowRecord
A DataFlowRecord represents a single deployment of a FlattenedDataFlowDescriptor on an infrastructure, i.e. on a set of Zenoh-Flow runtimes.
ReceiverRecord
A ReceiverRecord describes the receiving end of a “Zenoh connection” between Zenoh-Flow runtimes.
SenderRecord
A SenderRecord describes the sending end of a “Zenoh connection” between Zenoh-Flow runtimes.